{% load minimizer_tags %}

<!doctype html>
<!--[if lt IE 7]> <html class="no-js ie6 oldie" lang="en"> <![endif]-->
<!--[if IE 7]>    <html class="no-js ie7 oldie" lang="en"> <![endif]-->
<!--[if IE 8]>    <html class="no-js ie8 oldie" lang="en"> <![endif]-->
<!--[if gt IE 8]><!--> <html class="no-js" lang="en"> <!--<![endif]-->
    <head>
        <meta charset="utf-8">
        <meta http-equiv="X-UA-Compatible" content="IE=edge,chrome=1">
        <title>{% block title %}{% endblock %}</title>
        <meta name="description" content="{{ MINIMIZER_DESCRIPTION }}">
        <meta name="author" content="{{ MINIMIZER_AUTHOR }}">
        <meta name="viewport" content="width=device-width,initial-scale=1">
        {% block extraheads %}{% endblock %}
        {% minimizer_styles %}
        <script src="{{ STATIC_URL }}minimizer/js/modernizr-2.0.6.min.js"></script>
    </head>

    <body>
        {% block minimizer_content %}{% endblock %}

        <script src="//ajax.googleapis.com/ajax/libs/jquery/{{ MINIMIZER_JQUERY_VERSION }}/jquery.min.js"></script>
        <script>window.jQuery || document.write('<script src="{{ STATIC_URL }}minimizer/js/jquery-{{ MINIMIZER_JQUERY_VERSION }}.min.js"><\/script>')</script>

        {% block javascripts %}{% endblock %}
        {% minimizer_scripts %}

        {% if MINIMIZER_GOOGLE_ANALYTICS_CODE %}
            <script>
                window._gaq = [['_setAccount','{{ MINIMIZER_GOOGLE_ANALYTICS_CODE }}'],['_trackPageview'],['_trackPageLoadTime']];
                Modernizr.load({
                    load: ('https:' == location.protocol ? '//ssl' : '//www') + '.google-analytics.com/ga.js'
                });
            </script>
        {% endif %}

        <!--[if lt IE 7 ]>
            <script src="//ajax.googleapis.com/ajax/libs/chrome-frame/1.0.3/CFInstall.min.js"></script>
            <script>window.attachEvent('onload',function(){CFInstall.check({mode:'overlay'})})</script>
        <![endif]-->
    </body>
</html>
